@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -57,16 +57,14 @@ void activate_button_clicked(struct w *widgets)
     }
     g_free(path);
 
-    /* Apply the client settings. Writes client conf and sysinit script */
-    apply_client_settings(widgets);
-
     /* Switch to the notebooks progress/log tab */
     gtk_notebook_set_current_page(GTK_NOTEBOOK(widgets->main_notebook), 1);
-    /* Sleep 3 seconds and then populate it */
-    sleep(3);
-    populate_log_tab(widgets);
 
     /* Start the gadmin-openvpn-client runlevel script and
        make it start at boot if specified. */
     init_start(widgets);
+
+    /* Sleep 5 seconds and then populate it */
+    sleep(5);
+    populate_log_tab(widgets);
 }
