@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -169,6 +169,7 @@ void apply_client_settings(struct w *widgets)
     gchar *sysinit_script_path, *sysinit_start_script;
     gchar *conf_data=NULL, *openvpn_client_conf=NULL;
     gchar *pass_file, *pass_lines;
+    gchar *upscript, *upscript_path;
     // Use later if the OpenVPN server begins using encrypted passwords:
     // const char *encrypted_pass;
     gchar *firestarter_start, *firestarter_stop;
@@ -330,19 +331,6 @@ void apply_client_settings(struct w *widgets)
 	    return;
 	}
     }
-/*
-	path = g_strdup_printf("%s/client/%s", OPENVPN_SYSCONF_DIR, connection_name);
-	if( file_exists(path) )
-	{
-	    info = g_strdup_printf("%s", _("A connection with this name already exists.\n"));
-	    show_info(info);
-	    g_free(info);
-	    if( connection_name!=NULL )
-	      g_free(connection_name);
-	    return;
-	}
-    }
-*/
 
     if( ! add_new_connection )
     {
@@ -516,8 +504,6 @@ void apply_client_settings(struct w *widgets)
 	share_tunnel_with_lan = g_strconcat(
 	IP_FORWARD_CMD_START, "\n",
 	NULL);
-//	"# Needs fixing. Requires LAN addr and subnet mask. Not interfaced yet.\n",
-//	"echo \"iptables -t nat -A POSTROUTING -s LAN_ADDR/LAN_SUBN_MASK -o eth0 or tap0\"\n",
     }
 
     /* Firestarter start and stop script parts if used. */
@@ -525,17 +511,17 @@ void apply_client_settings(struct w *widgets)
     if( active_index == 1 )
     {
 	firestarter_start = g_strconcat(
-	"# Start Firestarter if its not running.\n",
-	"if [ ! -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
-	"    ", FIRESTARTER_BINARY, " -s\n",
-	"fi\n",
+	"	# Start Firestarter if its not running.\n",
+	"	if [ ! -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
+	"		", FIRESTARTER_BINARY, " -s\n",
+	"	fi\n",
 	NULL);
 
 	firestarter_stop = g_strconcat(
-	"# Stop Firestarter if its running.\n",
-	"if [ -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
-	"    ", FIRESTARTER_BINARY, " -p\n",
-	"fi\n",
+	"	# Stop Firestarter if its running.\n",
+	"	if [ -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
+	"    		", FIRESTARTER_BINARY, " -p\n",
+	"	fi\n",
 	NULL);
 	
 	non_firestarter_start = g_strdup_printf("\n");
@@ -544,39 +530,14 @@ void apply_client_settings(struct w *widgets)
     else
     {
 	/* Instead of firestarter configuring iptables, we do it. */
-
-	/* Get the LAN network address. Snip at the last dot. */
-/*
-	lan_net_addr = g_strdup_printf("%s", lan_iface_address);
-	for(i=strlen(lan_net_addr)-1; lan_net_addr[i]!='\0'; i--)
-	if( lan_net_addr[i]=='.')
-	{
-	    lan_net_addr[i+1]='0';
-	    lan_net_addr[i+2]='\0';
-	    break;
-	}
-*/
-
 	non_firestarter_start = g_strconcat("",
-	"# Run some iptable rules for the VPN-client.\n",
-	"iptables -A INPUT  -i tap+ -j ACCEPT\n",
-	"iptables -A OUTPUT -o tap+ -j ACCEPT\n",
-	"iptables -A FORWARD -i tap+ -j ACCEPT\n",
+	"	# Run some iptable rules for the VPN-client.\n",
+	"	iptables -A INPUT  -i tap+ -j ACCEPT\n",
+	"	iptables -A OUTPUT -o tap+ -j ACCEPT\n",
+	"	iptables -A FORWARD -i tap+ -j ACCEPT\n",
 	NULL);
-//	share_tunnel_with_lan, Fixit, add above...
-//	g_free(lan_net_addr);
 
-	/* Disallow input and output on tap interface 
-	   Restart the network interface */
-/*
-	non_firestarter_stop = g_strconcat(
-	"iptables -D INPUT  -i tap+ -j ACCEPT\n",
-	"iptables -D OUTPUT -o tap+ -j ACCEPT\n",
-// Not required 	"ifdown ", lan_iface_name, "\n",
-//	"ifup ", lan_iface_name, "\n",
-	NULL);
-*/
-	/* Dont remove internet sharing and other, possibly vital stuff */
+	/* Dont remove internet sharing and other vital stuff */
 	firestarter_start = g_strdup_printf("\n");
 	firestarter_stop  = g_strdup_printf("\n");
     }
@@ -646,16 +607,13 @@ void apply_client_settings(struct w *widgets)
     "status ", OPENVPN_SYSCONF_DIR, "/client/", selected_connection, "/openvpn-client-status.log\n",
     "verb ", log_level, "\n",
     "mute 20\n",
+    "ping 10\n",
+    "ping-restart 30\n",
+    "allow-pull-fqdn\n",
+    "resolv-retry infinite\n",
+    "up ", OPENVPN_SYSCONF_DIR, "/client/", selected_connection, "/upscript.sh\n",
     NULL);
 
-/*
-    "ca   certs/cacert.pem\n",
-    "cert certs/cert.pem\n",
-    "key  certs/key.pem\n",
-    "dh   certs/dh.pem\n",
-    "tls-auth certs/ta.key 1\n",
-*/
-
     fputs(conf_data, fp);
     fclose(fp);
     g_free(conf_data);
@@ -682,8 +640,8 @@ void apply_client_settings(struct w *widgets)
     "#\n",
     "### BEGIN INIT INFO\n",
     "# Provides: gadmin-openvpn-client\n",
-    "# Required-Start: network NetworkManager\n",
-    "# Required-Stop: NetworkManager\n",
+    "# Required-Start: $network\n",
+    "# Required-Stop: $network\n",
     "# Default-Start: 2 3 4 5\n",
     "# Default-Stop: 0 1 6\n",
     "# Short-Description: start and stop gadmin-openvpn-client\n",
@@ -691,43 +649,40 @@ void apply_client_settings(struct w *widgets)
     "### END INIT INFO\n",
     "\n",
     start_at_boot_label,
-    "\n",
-    mountcmd,
-    "\n",
-//    "lan_eth=\"", lan_iface_name, "\"\n",
-//    "lan_eth_ip=\"", lan_iface_address, "\"\n",
-//    "lan_eth_netmask=\"", lan_subnet_mask, "\"\n",
-//    "lan_eth_broadcast=\"", lan_broadcast_address, "\"\n",
-//    "\n",
     "\n",
     "case \"$1\" in\n",
-    "		start)\n",
+    "	start)\n",
     "\n",
-    firestarter_stop,
+    "	", firestarter_stop,
     "\n",
-    "modprobe tun\n",
+    "	modprobe tun\n",
+    "	mkdir -p /var/run/openvpn\n",
     "\n",
-    "openvpn --daemon --script-security 2 --writepid /var/run/openvpn/openvpn-client.pid \\\n",
-    "--config ", OPENVPN_SYSCONF_DIR, "/client/", selected_connection, "/gadmin-openvpn-client.conf \\\n",
-    "--cd ", OPENVPN_SYSCONF_DIR, "/client/", selected_connection, "\n",
+    "	", mountcmd,
     "\n",
-    firestarter_start,
-    non_firestarter_start,
-    share_tunnel_with_lan,
-    ";;\n",
+    "	openvpn --daemon --script-security 2 --writepid /var/run/openvpn/openvpn-client.pid \\\n",
+    "	--config ", OPENVPN_SYSCONF_DIR, "/client/", selected_connection, "/gadmin-openvpn-client.conf \\\n",
+    "	--cd ", OPENVPN_SYSCONF_DIR, "/client/", selected_connection, "\n",
     "\n",
-    "		stop)\n",
+    "	", firestarter_start,
+    "	", non_firestarter_start,
+    "	", share_tunnel_with_lan,
+    "	;;\n",
+    "	stop)\n",
     "\n",
-// Use: kill cat pid here 
-    "killall -9 openvpn\n",
+    "	killall -9 openvpn &> /dev/null\n",
     "\n",
-//    non_firestarter_stop,
+    "	# Revert any changes made by the push pull DNS and domain settings.\n",
+    "	if [ -e /etc/resolv.conf.gadmin.orig ] &&\n",
+    "           grep -q \"nameserver\" /etc/resolv.conf.gadmin.orig ; then\n",
+    "	   cat /etc/resolv.conf.gadmin.orig > /etc/resolv.conf\n",
+    "	fi\n",
     "\n",
-    ";;\n",
-    "		*)\n",
-    "echo \"usage gadmin-openvpn-client {start|stop}\"\n",
-    "exit 1\n",
-    ";;\n",
+    "	;;\n",
+    "	*)\n",
+    "	echo \"usage gadmin-openvpn-client {start|stop}\"\n",
+    "	exit 1\n",
+    "	;;\n",
     "esac\n",
     "\n",
     "exit 0\n",
@@ -737,7 +692,6 @@ void apply_client_settings(struct w *widgets)
     g_free(firestarter_start);
     g_free(firestarter_stop);
     g_free(non_firestarter_start);
-//    g_free(non_firestarter_stop);
     g_free(start_at_boot_label);
     g_free(share_tunnel_with_lan);
 
@@ -769,6 +723,48 @@ void apply_client_settings(struct w *widgets)
     g_free(sysinit_script_path);
 
 
+    /* Write an upscript */
+    upscript_path = g_strdup_printf("%s/client/%s/upscript.sh", OPENVPN_SYSCONF_DIR, selected_connection);
+    if((fp=fopen(upscript_path, "w+"))==NULL)
+    {
+	info = g_strdup_printf(_("Can not write the openvpn client upscript here: \n%s\n"), upscript_path);
+	show_info(info);
+	g_free(info);
+	g_free(upscript_path);
+        return;
+    }
+    upscript = g_strconcat(
+    "#!/bin/bash\n",
+    "### Copy the clients pulled environment and transfer options\n",
+    "### such as domain and nameservers to /etc/resolv.conf.\n",
+    "### The changes are reverted when gadmin-openvpn-client is deactivated.\n",
+    "\n",
+    "env > /etc/gadmin-openvpn-client.env\n",
+    "\n",
+    "### Set search domain and DNS-addresses first in the conf.\n",
+    "\n",
+    "grep \"dhcp-option DNS\" /etc/gadmin-openvpn-client.env &> /dev/null && \n",
+    "cat /etc/resolv.conf > /etc/resolv.conf.gadmin.orig &&\n",
+    "echo > /etc/resolv.conf &&\n",
+    "grep \"dhcp-option DOMAIN\" /etc/gadmin-openvpn-client.env | awk '{print \"search \" $3}' >> /etc/resolv.conf ; \\\n",
+    "grep \"dhcp-option DNS\"    /etc/gadmin-openvpn-client.env | awk '{print \"nameserver \" $3}' >> /etc/resolv.conf\n",
+    "grep \"nameserver\" /etc/resolv.conf.gadmin.orig >> /etc/resolv.conf\n",
+    "\n",
+    NULL);    
+    fputs(upscript, fp);
+    fclose(fp);
+    g_free(upscript);
+
+    /* Chmod the script to 755 */
+    cmd = g_strdup_printf("chmod 755 %s", upscript_path);
+    if( ! run_command(cmd) )
+    {
+	printf("Show popup, error chmodding the upscript.\n");
+    }
+    g_free(cmd);
+    g_free(upscript_path);
+
+
     /* Populate the client settings */
     populate_connections(widgets);
 
