@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,15 +30,18 @@
 #include "commands.h"
 #include "show_info.h"
 #include "allocate.h"
+#include "clear_log_tab.h"
 
 extern int activated;
 
 
-
 void deactivate_button_clicked(struct w *widgets)
 {
     if( ! activated )
       return;
 
+    /* Clear the log tab */
+    clear_log_tab(widgets);
+
     init_stop(widgets);
 }
