@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,9 @@
 #include "populate_client_settings.h"
 
 
+extern gchar *selected_connection;
+
+
 
 void save_conf_tab(struct w *widgets)
 {
@@ -41,7 +44,8 @@ void save_conf_tab(struct w *widgets)
     gchar *conf = NULL;
     gchar *utf8 = NULL;
 
-    gchar *openvpn_client_conf = g_strdup_printf("%s/client/gadmin-openvpn-client.conf", OPENVPN_SYSCONF_DIR);
+    gchar *openvpn_client_conf = g_strdup_printf("%s/client/%s/gadmin-openvpn-client.conf",
+						    OPENVPN_SYSCONF_DIR, selected_connection);
 
     conf_textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(widgets->conf_textview));
     gtk_text_buffer_get_bounds(conf_textbuffer, &start, &end);
